==> haskell-src-exts-simple-1.23.1.0-83.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-src-exts-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src-exts-simple
version:              1.23.1.0
visibility:           public
id:                   haskell-src-exts-simple-1.23.1.0-DKZ3kij2iKbAkES4qydCyX
key:                  haskell-src-exts-simple-1.23.1.0-DKZ3kij2iKbAkES4qydCyX
license:              MIT
copyright:            2016-2024, Bertram Felgenhauer
maintainer:           Bertram Felgenhauer <int-e@gmx.de>
author:               Bertram Felgenhauer
homepage:             https://github.com/int-e/haskell-src-exts-simple
synopsis:             A simplified view on the haskell-src-exts AST
description:
    This package provides a shim for haskell-src-exts (HSE), exposing the
    same AST but without annotations, using ghc'\''s pattern synonyms.

    See README.md for further information and compatibility considerations.

category:             Development
abi:                  3de6a68740842c0b0fb994fc4b7677b3
exposed:              True
exposed-modules:
    Language.Haskell.Exts.Simple Language.Haskell.Exts.Simple.Build
    Language.Haskell.Exts.Simple.Extension
    Language.Haskell.Exts.Simple.Fixity
    Language.Haskell.Exts.Simple.Parser
    Language.Haskell.Exts.Simple.Pretty
    Language.Haskell.Exts.Simple.Syntax

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-src-exts-simple-1.23.1.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-src-exts-simple-1.23.1.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-src-exts-simple-1.23.1.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-exts-simple
hs-libraries:         HShaskell-src-exts-simple-1.23.1.0-DKZ3kij2iKbAkES4qydCyX
depends:
    base-4.18.2.1 haskell-src-exts-1.23.1-F3jL8MeOgpf1H3BDGTEVcV

haddock-interfaces:
    /usr/share/doc/haskell-src-exts-simple/html/haskell-src-exts-simple.haddock

haddock-html:         /usr/share/doc/haskell-src-exts-simple/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-exts-simple-1.23.1.0-84-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-src-exts-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src-exts-simple
version:              1.23.1.0
visibility:           public
id:                   haskell-src-exts-simple-1.23.1.0-IpWBt2Lw3bM8aD1efeZQpy
key:                  haskell-src-exts-simple-1.23.1.0-IpWBt2Lw3bM8aD1efeZQpy
license:              MIT
copyright:            2016-2024, Bertram Felgenhauer
maintainer:           Bertram Felgenhauer <int-e@gmx.de>
author:               Bertram Felgenhauer
homepage:             https://github.com/int-e/haskell-src-exts-simple
synopsis:             A simplified view on the haskell-src-exts AST
description:
    This package provides a shim for haskell-src-exts (HSE), exposing the
    same AST but without annotations, using ghc'\''s pattern synonyms.

    See README.md for further information and compatibility considerations.

category:             Development
abi:                  eaa7a2ce451791f954f6bf4623be188d
exposed:              True
exposed-modules:
    Language.Haskell.Exts.Simple Language.Haskell.Exts.Simple.Build
    Language.Haskell.Exts.Simple.Extension
    Language.Haskell.Exts.Simple.Fixity
    Language.Haskell.Exts.Simple.Parser
    Language.Haskell.Exts.Simple.Pretty
    Language.Haskell.Exts.Simple.Syntax

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-src-exts-simple-1.23.1.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-src-exts-simple-1.23.1.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-src-exts-simple-1.23.1.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-exts-simple
hs-libraries:         HShaskell-src-exts-simple-1.23.1.0-IpWBt2Lw3bM8aD1efeZQpy
depends:
    base-4.18.2.1 haskell-src-exts-1.23.1-63590nDmfj1880iQCS4JdS

haddock-interfaces:
    /usr/share/doc/haskell-src-exts-simple/html/haskell-src-exts-simple.haddock

haddock-html:         /usr/share/doc/haskell-src-exts-simple/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
